
/* Generated data (by glib-mkenums) */

#ifndef __GDK_PIXBUF_ENUM_TYPES_H__
#define __GDK_PIXBUF_ENUM_TYPES_H__

/* enumerations from "gdk-pixbuf.h" */

GType gdk_pixbuf_alpha_mode_get_type (void);
#define GDK_TYPE_PIXBUF_ALPHA_MODE (gdk_pixbuf_alpha_mode_get_type())

GType gdk_colorspace_get_type (void);
#define GDK_TYPE_COLORSPACE (gdk_colorspace_get_type())

GType gdk_pixbuf_error_get_type (void);
#define GDK_TYPE_PIXBUF_ERROR (gdk_pixbuf_error_get_type())

GType gdk_interp_type_get_type (void);
#define GDK_TYPE_INTERP_TYPE (gdk_interp_type_get_type())

#endif /* __GDK_PIXBUF_ENUM_TYPES_H__ */

/* Generated data ends here */

